@@ -41,12 +41,10 @@ class Results(object):
         :rtype: mixed
 
         """
-        if not self.cursor.rowcount:
-            raise StopIteration
-
-        self._rewind()
-        for row in self.cursor:
-            yield row
+        if self.cursor.rowcount:
+            self._rewind()
+            for row in self.cursor:
+                yield row
 
     def __len__(self):
         """Return the number of rows that were returned from the query
@@ -59,6 +57,9 @@ class Results(object):
     def __nonzero__(self):
         return bool(self.cursor.rowcount)
 
+    def __bool__(self):
+        return self.__nonzero__()
+
     def __repr__(self):
         return '<queries.%s rows=%s>' % (self.__class__.__name__, len(self))
 
@@ -92,7 +93,7 @@ class Results(object):
         connections.
 
         """
-        raise NotImplementedError
+        LOGGER.debug('Invoking synchronous free has no effect')
 
     def items(self):
         """Return all of the rows that are in the result set.
